@@ -4,19 +4,20 @@ use base qw(Number::Tolerant::Type);
 use strict;
 use warnings;
 
-our $VERSION = '1.540';
-
-my $number = $Number::Tolerant::Type::number;
-my $X = $Number::Tolerant::Type::X;
+our $VERSION = '1.550';
 
 sub construct { shift; $_[0] }
 
-sub parse { shift;
+sub parse {
+  my $self = shift;
+  my $number = $self->number_re;
   return $_[0] if ($_[0] =~ m!\A($number)\z!);
   return;
 }
 
-sub valid_args { shift;
+sub valid_args {
+  my $self = shift;
+  my $number = $self->number_re;
   return $_[0] if @_==1 and defined $_[0] and $_[0] =~ m!\A($number)\z!;
   return;
 }
