@@ -4,14 +4,15 @@ use base qw(Number::Tolerant::Type);
 use strict;
 use warnings;
 
-our $VERSION = '1.540';
-
-my $number = $Number::Tolerant::Type::number;
-my $X = $Number::Tolerant::Type::X;
+our $VERSION = '1.550';
 
 sub construct { shift; { value => $_[0], min => $_[0], exclude_min => 1 } }
 
-sub parse { shift;
+sub parse {
+  my $self = shift;
+  my $number = $self->number_re;
+  my $X = $self->variable_re;
+
   return Number::Tolerant::tolerance(more_than => "$1")
     if ($_[0] =~ m!\A($number)\s*<$X\z!);
   return Number::Tolerant::tolerance(more_than => "$1")
@@ -21,7 +22,10 @@ sub parse { shift;
   return;
 }
 
-sub valid_args { shift;
+sub valid_args {
+  my $self = shift;
+  my $number = $self->number_re;
+
   if ((grep { defined } @_) == 2) {
     return ($_[1]) if ($_[1] =~ $number) and ($_[0] eq 'more_than');
     return ($_[0]) if ($_[0] =~ $number) and ($_[1] eq 'more_than');
