@@ -4,10 +4,7 @@ use base qw(Number::Tolerant::Type);
 use strict;
 use warnings;
 
-our $VERSION = '1.540';
-
-my $number = $Number::Tolerant::Type::number;
-my $X = $Number::Tolerant::Type::X;
+our $VERSION = '1.550';
 
 sub construct { shift;
   {
@@ -18,8 +15,9 @@ sub construct { shift;
 }
 
 sub parse {
-  my (undef, $string) = @_;
+  my ($self, $string) = @_;
 
+  my $number = $self->number_re;
   return Number::Tolerant::tolerance("$1", 'offset', "$2", "$3")
     if ($string =~ m!\A($number)\s+\(?\s*($number)\s+($number)\s*\)?\s*\z!);
 
@@ -34,7 +32,10 @@ sub stringify {
     ($_[0]->{max} - $_[0]->{value});
 }
 
-sub valid_args { shift;
+sub valid_args {
+  my $self = shift;
+  my $number = $self->number_re;
+
   return ($_[0],$_[2], $_[3])
     if  (grep { defined } @_) == 4
     and $_[0] =~ $number
