@@ -4,10 +4,7 @@ use base qw(Number::Tolerant::Type);
 use strict;
 use warnings;
 
-our $VERSION = '1.540';
-
-my $number = $Number::Tolerant::Type::number;
-my $X = $Number::Tolerant::Type::X;
+our $VERSION = '1.550';
 
 sub construct { shift;
   {
@@ -18,7 +15,10 @@ sub construct { shift;
   }
 }
 
-sub parse { shift;
+sub parse {
+  my $self = shift;
+  my $number = $self->number_re;
+
   return Number::Tolerant::tolerance("$1", 'plus_or_minus_pct', "$2")
     if ($_[0] =~ m!\A($number)\s*\+/-\s*($number)%\z!);
   return;
@@ -26,7 +26,10 @@ sub parse { shift;
 
 sub stringify { "$_[0]->{value} +/- $_[0]->{variance}%" }
 
-sub valid_args { shift;
+sub valid_args {
+  my $self = shift;
+  my $number = $self->number_re;
+
   return ($_[0],$_[2])
     if ((grep { defined } @_) == 3)
     and ($_[0] =~ $number)
